@@ -15,6 +15,7 @@ from __future__ import absolute_import
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
+import atexit
 import codecs
 from contextlib import contextmanager
 import io
@@ -86,6 +87,7 @@ class IOStream:
 
 # setup stdin/stdout/stderr to sys.stdin/sys.stdout/sys.stderr
 devnull = open(os.devnull, 'w') 
+atexit.register(devnull.close)
 stdin = IOStream(sys.stdin, fallback=devnull)
 stdout = IOStream(sys.stdout, fallback=devnull)
 stderr = IOStream(sys.stderr, fallback=devnull)
@@ -223,7 +225,7 @@ def temp_pyfile(src, ext='.py'):
 
 def _copy_metadata(src, dst):
     """Copy the set of metadata we want for atomic_writing.
-
+    
     Permission bits and flags. We'd like to copy file ownership as well, but we
     can't do that.
     """
@@ -235,28 +237,28 @@ def _copy_metadata(src, dst):
 @contextmanager
 def atomic_writing(path, text=True, encoding='utf-8', **kwargs):
     """Context manager to write to a file only if the entire write is successful.
-
+    
     This works by creating a temporary file in the same directory, and renaming
-    it over the old file if the context is exited without an error. If the
-    target file is a symlink or a hardlink, this will not be preserved: it will
-    be replaced by a new regular file.
-
+    it over the old file if the context is exited without an error. If other
+    file names are hard linked to the target file, this relationship will not be
+    preserved.
+    
     On Windows, there is a small chink in the atomicity: the target file is
     deleted before renaming the temporary file over it. This appears to be
     unavoidable.
-
+    
     Parameters
     ----------
     path : str
       The target file to write to.
-
+     
     text : bool, optional
       Whether to open the file in text mode (i.e. to write unicode). Default is
       True.
-
+    
     encoding : str, optional
       The encoding to use for files opened in text mode. Default is UTF-8.
-
+     
     **kwargs
       Passed to :func:`io.open`.
     """
@@ -267,17 +269,18 @@ def atomic_writing(path, text=True, encoding='utf-8', **kwargs):
         path = os.path.join(os.path.dirname(path), os.readlink(path))
 
     dirname, basename = os.path.split(path)
-    handle, tmp_path = tempfile.mkstemp(prefix=basename, dir=dirname, text=text)
+    tmp_dir = tempfile.mkdtemp(prefix=basename, dir=dirname)
+    tmp_path = os.path.join(tmp_dir, basename)
     if text:
-        fileobj = io.open(handle, 'w', encoding=encoding, **kwargs)
+        fileobj = io.open(tmp_path, 'w', encoding=encoding, **kwargs)
     else:
-        fileobj = io.open(handle, 'wb', **kwargs)
+        fileobj = io.open(tmp_path, 'wb', **kwargs)
 
     try:
         yield fileobj
     except:
         fileobj.close()
-        os.remove(tmp_path)
+        shutil.rmtree(tmp_dir)
         raise
 
     # Flush to disk
@@ -299,6 +302,7 @@ def atomic_writing(path, text=True, encoding='utf-8', **kwargs):
         os.remove(path)
 
     os.rename(tmp_path, path)
+    shutil.rmtree(tmp_dir)
 
 
 def raw_print(*args, **kw):
